Changelog
---------

.. changelog::
    :changelog-url: https://disease-normalizer.readthedocs.io/en/stable/#changelog
    :github: https://github.com/cancervariants/disease-normalization/releases/
    :pypi: https://pypi.org/project/disease-normalizer/
